nvector.objects.FrameN — nvector 0.7.5 documentation

# nvector.objects.FrameN

class `FrameN`(position)

  > North-East-Down frame

  Parameters
    position: ECEFvector, GeoPoint or Nvector object

      position of the vehicle (B) which also defines the origin of the local frame N. The origin is directly beneath or above the vehicle (B), at Earth’s surface (surface of ellipsoid model).

  Notes

  The Cartesian frame is local and oriented North-East-Down, i.e., the x-axis points towards north, the y-axis points towards east (both are horizontal), and the z-axis is pointing down.

  When moving relative to the Earth, the frame rotates about its z-axis to allow the x-axis to always point towards north. When getting close to the poles this rotation rate will increase, being infinite at the poles. The poles are thus singularities and the direction of the x- and y-axes are not defined here. Hence, this coordinate frame is NOT SUITABLE for general calculations.

  `__init__`(self, position)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `Pvector`(self, pvector) | Returns Pvector relative to the local frame.
  `__init__`(self, position) | Initialize self.

  Attributes

  `R_EN` | Rotation matrix to go between E and N frame